@@ -1,6 +1,6 @@
 import numpy as np
 
-class Sigmod:
+class Sigmoid:
     def activate(self, x):
         return 1/(1 + np.exp(-x))
     def derivative(self, x):
